"""
Plot CFD data compared to blades
"""

import matplotlib.pyplot as plt
import numpy as np
from scipy import ndimage
from scipy import interpolate

# Set user variables here
voting_threshold = 1000
cfd_file = 'TipClearance.csv'

# Read in blade geometry coordinates
blade = np.genfromtxt('bladegeometry.txt', delimiter=',', skip_header=1,
                     names=['axial', 'tan'])

# Read in data
data = np.genfromtxt('./CFD/%s' % cfd_file, delimiter=',', skip_header=7,
                     names=['axial', 'tan','radial','p','V','u','v','w'])


# Set up a regular grid of interpolation points
x = data['axial']*1000
y = data['tan']*1000
phi = data['V']

# Add periodic data (put in four sets to get good data - bit of a hack!)
# There is probably a better way of doing this.....
xl = np.append(x,x)
yl = np.append(y-191,y-382)
phil = np.append(phi,phi)

xu = np.append(x,x)
yu = np.append(y+191,y)
phiu = np.append(phi,phi)

x = np.append(xu,xl)
y = np.append(yu,yl)
phi = np.append(phiu,phil)

xi, yi = np.linspace(x.min(), x.max(), 1000), np.linspace(y.min(), y.max(), 1000)
xi, yi = np.meshgrid(xi, yi)
zi = interpolate.griddata((x, y), phi, (xi, yi), method='linear')


# *** Plot Number One ***
plt.imshow(zi, vmin=phi.min(), vmax=phi.max(), origin='lower',
           extent=[x.min(), x.max(), y.min(), y.max()],zorder=0)
plt.colorbar(label="V / [ms/]")

# Plot some blade outlines over the top
plt.plot(blade['axial'],blade['tan'],'g-',lw=3)
plt.plot(blade['axial'],blade['tan']-191,'g-',lw=3)
plt.plot(blade['axial'],blade['tan']-191-191,'g-',lw=3)
plt.xlabel("axial / [mm]")
plt.ylabel("tan / [mm]")
# Set some limits to crop the image
plt.xlim(-200,25)
plt.ylim(-225,125)

plt.savefig('%s_velocity.png' % cfd_file, bbox_inches='tight',dpi=300)
#plt.show()
plt.close()

# *** Plot Number Two ***
# Streamplot stuff

U = data['u']
V = data['v']
U = np.append(np.append(U,U),np.append(U,U))
V = np.append(np.append(V,V),np.append(V,V))

xi, yi = np.linspace(x.min(), x.max(), 200), np.linspace(y.min(), y.max(), 200)
xi, yi = np.meshgrid(xi, yi)
Ui = interpolate.griddata((x, y), U, (xi, yi), method='linear')
Vi = interpolate.griddata((x, y), V, (xi, yi), method='linear')


# matplotlib was not respecting the axis settings when using quiver or streamlines
# this is a hack to get around that
blank = plt.imread('blank.png')
plt.imshow(blank, vmin=phi.min(), vmax=phi.max(), origin='lower',
           extent=[x.min(), x.max(), y.min(), y.max()],zorder=0)

# plt.streamplot(xi, yi, Ui, Vi,density=5, linewidth=2, cmap=plt.cm.autumn)

plt.plot(blade['axial'],blade['tan'],'g-',lw=3)
plt.plot(blade['axial'],blade['tan']-191,'g-',lw=3)
plt.plot(blade['axial'],blade['tan']-191-191,'g-',lw=3)
plt.xlabel("axial / [mm]")
plt.ylabel("tan / [mm]")
plt.xlim(-200,25)
plt.ylim(-225,125)
plt.savefig('%streamplot.png' % cfd_file, bbox_inches='tight',dpi=300)
# plt.show()
plt.close()

# *** Plot Number Three ***
# Vector stuff
plt.imshow(blank, vmin=phi.min(), vmax=phi.max(), origin='lower',
           extent=[x.min(), x.max(), y.min(), y.max()],zorder=0)
plt.quiver(xi, yi, Ui, Vi,units='width',scale=100)
# plt.quiver(xi, yi, Ui, Vi,units='xy')
plt.plot(blade['axial'],blade['tan'],'g-',lw=3)
plt.plot(blade['axial'],blade['tan']-191,'g-',lw=3)
plt.plot(blade['axial'],blade['tan']-191-191,'g-',lw=3)
plt.xlabel("axial / [mm]")
plt.ylabel("tan / [mm]")
plt.xlim(-200,25)
plt.ylim(-225,125)
plt.savefig('%svector.png' % cfd_file, bbox_inches='tight',dpi=300)
# plt.show()
